Crate locket

Crate locket 

locket

locket is a secret management agent and helper library designed to orchestrate secrets for dependent applications. It creates a bridge between secret providers and applications by injecting secrets into configuration files or environment variables.

Feature Flags

  • op: Enables the 1Password Service Account provider.
  • connect: Enables the 1Password Connect provider.
  • bws: Enables the Bitwarden Secrets Manager provider.
  • compose: Enables Docker CLI Plugin for use as a Docker Compose Provider service
  • exec: Enables the exec command for process environment injection into a child process
  • volume: Enables the volume command for use as a Docker volume driver.

Modules

cmd
CLI entry point and subcommand dispatch.
compose
Docker Compose provider communication and error handling.
config
Configuration layering
env
Secret environment variable management, handling injection and resolution.
error
events
Core interfaces for event handling.
health
Healthcheck probe for the locket inject sidecar service.
logging
Logging configuration for general purpose use, with clap configuration.
path
Filesystem path normalization and security utilities.
process
Process lifecycle management and signal proxying.
provider
Secrets provider abstractions and implementations.
secrets
Core primitives for secret management and definition.
template
Template parsing and rendering for secret references.
volume
watch
Filesystem watching with debouncing and event coalescing.
write
Utilities for writing files atomically with explicit permissions.