Module process

Module process 

Process lifecycle management and signal proxying.

Implements the ProcessManager, which spawns and manages a child process with a dynamically resolved environment. It listens for filesystem events via the EventHandler trait, and restarts the child process when relevant changes occur.

Structs

ProcessManager
Manages a child process, restarting it when the environment changes.
ProcessTimeout
Default timeout for waiting for a child process to exit gracefully after SIGTERM.
ShellCommand
Represents a shell command to be executed, including the program and its arguments. The arguments may be empty, but at least a program must be specified.

Enums

ProcessError
Errors specific to process lifecycle management.