pub struct ProcessTimeout(pub Duration);Expand description
Default timeout for waiting for a child process to exit gracefully after SIGTERM.
Tuple Fields
0: DurationTrait Implementations
Sourceimpl Clone for ProcessTimeout
impl Clone for ProcessTimeout
Sourcefn clone(&self) -> ProcessTimeout
fn clone(&self) -> ProcessTimeout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTimeout
impl Debug for ProcessTimeout
Sourceimpl Default for ProcessTimeout
impl Default for ProcessTimeout
Sourceimpl<'de> Deserialize<'de> for ProcessTimeout
impl<'de> Deserialize<'de> for ProcessTimeout
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProcessTimeout
impl Display for ProcessTimeout
Sourceimpl From<ProcessTimeout> for Duration
impl From<ProcessTimeout> for Duration
Sourcefn from(val: ProcessTimeout) -> Self
fn from(val: ProcessTimeout) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for ProcessTimeout
Defaults to seconds if no unit specified, otherwise uses humantime parsing.
impl FromStr for ProcessTimeout
Defaults to seconds if no unit specified, otherwise uses humantime parsing.
Sourceimpl Serialize for ProcessTimeout
impl Serialize for ProcessTimeout
Sourceimpl TryFrom<String> for ProcessTimeout
impl TryFrom<String> for ProcessTimeout
impl Copy for ProcessTimeout