pub struct ShellCommand { /* private fields */ }Expand description
Represents a shell command to be executed, including the program and its arguments. The arguments may be empty, but at least a program must be specified.
Implementations
Sourceimpl ShellCommand
impl ShellCommand